@@ -1,6 +1,9 @@
 package Lingua::ID::Nums2Words;
 
-use 5.010;
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.04'; # VERSION
+
+use 5.010001;
 use strict;
 use warnings;
 
@@ -10,8 +13,6 @@ our @EXPORT_OK = qw(nums2words nums2words_simple);
 
 our %SPEC;
 
-our $VERSION = '0.03'; # VERSION
-
 use vars qw(
     $Dec_char
     $Neg_word
@@ -215,17 +216,19 @@ sub _join_it(@) {
 1;
 # ABSTRACT: Convert number to Indonesian verbage
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Lingua::ID::Nums2Words - Convert number to Indonesian verbage
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of Lingua::ID::Nums2Words (from Perl distribution Lingua-ID-Nums2Words), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -240,20 +243,78 @@ This module provides two functions, B<nums2words> and B<nums2words_simple>, to
 convert number to Indonesian verbage. Popular Indonesian term for this kind of
 library is "terbilang", or roughly "spelled amount" in English.
 
+=head1 FUNCTIONS
+
+
+=head2 nums2words($num) -> any
+
+Convert number to Indonesian verbage.
+
+This is akin to converting 123 to "a hundred and twenty three" in English.
+Currently can handle real numbers in normal and scientific form in the order of
+hundreds of trillions. It also preserves formatting in the number string (e.g,
+given "1.00" C<nums2words> will pronounce the zeros.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num>* => I<str>
+
+The number to convert.
+
+=back
+
+Return value:  (any)
+
+
+=head2 nums2words_simple($num) -> any
+
+Like nums2words but only pronounce the digits.
+
+This is akin to converting 123 to "one two three" in English.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num>* => I<str>
+
+The number to convert.
+
+=back
+
+Return value:  (any)
+
 =head1 SEE ALSO
 
 L<Lingua::ID::Words2Nums>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Lingua-ID-Nums2Words>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Lingua-ID-Nums2Words>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-ID-Nums2Words>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
